/*
This SQL script was created to change your docMgt DB to use the SQL-based full text search method.
In order to use this you must have the following in place:

	1) SQL Server Full Text engine must be installed on your SQL server. If you have an existing SQL server 
	installation and need to add Full Text to it, here is an article that may help.
	https://www.techrepublic.com/blog/data-center/adding-sql-full-text-search-to-an-existing-sql-server/

	2) You must NOT already have existing OCR (Full Text) data stored in your docMgt database. If you run this script 
	while you have existing Full Text data you will no longer be able to search based on your old data. If you have
	existing Full Text data then you will need to convert the existing OCR data from the DocumentFullText table
	to this new format. Contact support for help with this.

	3) If you are using SQL Server Express (NOT recommended for full text data) you must be sure you are using the 
	correct version that includes the full text engine. You must install the SQL Server Express Advanced Edition in 
	that case. Be sure you have that in place before running this script.

*/


/*
Make sure full text is enabled for server (This will not work in Azure so comment out for Azure installs)
*/
sp_fulltext_database 'enable' 


/*
This script will only enable the advanced full text searching if you have not already used OCR in docMgt
If you have used OCR then you will need to convert the existing OCR data from the DocumentFullText table
to this new format. Contact support for help with this.
*/
IF EXISTS (SELECT * FROM sys.databases WHERE database_id = DB_ID() AND is_fulltext_enabled=1) 
	--Comment out the next line ONLY if preparing for the Full Text Conversion (as per docMGt Support!)
	AND NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[DocumentFullText]') AND type in (N'U')) OR NOT EXISTS (SELECT 1 FROM DocumentFullText) 
BEGIN

	
	--Create a stoplist to ignore the wrapper object in the Words column
	IF NOT EXISTS (SELECT * FROM sys.fulltext_stoplists WHERE name='dmStopList')
	BEGIN
		CREATE FULLTEXT STOPLIST dmStopList FROM SYSTEM STOPLIST; 
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Confidence' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Document' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Height' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Width' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Top' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Left' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'PageNumber' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'SmallPhrase' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Source' LANGUAGE 'English';
		ALTER FULLTEXT STOPLIST dmStopList ADD 'Word' LANGUAGE 'English';
	END


		-- Add the ocumentFullText2 table if not already there
		IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[DocumentFullText2]') AND type in (N'U'))
		BEGIN
		CREATE TABLE [DocumentFullText2](
			[ID] [int] IDENTITY(1,1) NOT NULL,
			[DocumentID] [int] NOT NULL,
			[PageNumber] [int] NOT NULL,
			[Words] [TEXT] NULL
		 CONSTRAINT [DocumentFullText2_PRIMARY] PRIMARY KEY NONCLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)
		)
		END
		IF NOT EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[DocumentFullText2]') AND name = N'idx_DocumentFullText2_DocumentID')
			CREATE INDEX [idx_DocumentFullText2_DocumentID] ON [DocumentFullText2] (DocumentID)
	
		-- Document Full Text
		-- Create Full Text Calalog
		IF NOT EXISTS (SELECT 1 FROM sys.fulltext_catalogs WHERE [name] = 'DocumentTextCatalog')
			CREATE FULLTEXT CATALOG DocumentTextCatalog; 
		-- Create Full Iext Index 
		IF NOT EXISTS (SELECT * FROM sys.fulltext_indexes WHERE object_id = object_id('[DocumentFullText2]') ) 
			CREATE FULLTEXT INDEX ON [DocumentFullText2] ([Words]) KEY INDEX DocumentFullText2_PRIMARY ON DocumentTextCatalog; 

		IF EXISTS (SELECT * FROM sys.fulltext_indexes WHERE object_id = object_id('[DocumentFullText2]') ) 
			-- Enable the index 
			ALTER FULLTEXT INDEX ON [DocumentFullText2] Set StopList dmStopList
			-- Use the StopList
			ALTER FULLTEXT INDEX ON [DocumentFullText2] ENABLE; 


		--DATA Table (we also enable full text searching on the Data table with this method)
		--Create full text catalog
		IF NOT EXISTS (SELECT 1 FROM sys.fulltext_catalogs WHERE [name] = 'DataCatalog')
			CREATE FULLTEXT CATALOG DataCatalog; 
		-- Create full text index
		IF NOT EXISTS (SELECT * FROM sys.fulltext_indexes WHERE object_id = object_id('[Data]') ) 
			CREATE FULLTEXT INDEX ON [Data] ([DataValue], [DataValueLarge], [DataValueMax]) KEY INDEX Data_PRIMARY ON DataCatalog;
		-- Enable the index 
		IF EXISTS (SELECT * FROM sys.fulltext_indexes WHERE object_id = object_id('[Data]') ) 
			ALTER FULLTEXT INDEX ON [Data] ENABLE; 

END
